==> etlutils-0.2.tar.gz: etlutils-0.2/README.md <==
[![PyPI version](https://badge.fury.io/py/etlutils.svg)](https://pypi.org/project/etlutils/)
[![Python versions](https://img.shields.io/pypi/pyversions/etlutils)](https://pypi.org/project/etlutils/)
[![Documentation Status](https://readthedocs.org/projects/etlutils/badge/?version=latest)](https://etlutils.readthedocs.io/en/latest/?badge=latest)
[![contributions welcome](https://img.shields.io/badge/contributions-welcome-brightgreen.svg?style=flat)](https://github.com/kevingoldsmith/etlutils/issues)
[![Twitter](https://img.shields.io/twitter/follow/kevingoldsmith?style=plastic)](https://img.shields.io/twitter/follow/kevingoldsmith?style=plastic)

# etlutils

This is a collection of utility functions for my etl projects. Sharing as they might be useful to others as well.

## current version

The current version is 0.1 as this is a very early release. Use at your own risk as things will change.

## documentation

Read the documentation on [readthedocs](https://etlutils.readthedocs.io/en/latest/)

## installing with pip

    pip install etlutils

## building for development

    make init
    pip install -e .
    make test
    make lint

## contributions

All contributions are welcome, please submit a PR. Issues and feature requests are fine as well, but they may take some time for me to get to. Better to submit a PR.

## requires

Python 3.6 or above, I'm not using any earlier versions of python on any of my projects anymore, so supporting older versions isn't high on my list of priorities.

==> etlutils-0.2.2.tar.gz: etlutils-0.2.2/README.md <==
[![PyPI version](https://badge.fury.io/py/etlutils.svg)](https://pypi.org/project/etlutils/)
[![Python versions](https://img.shields.io/pypi/pyversions/etlutils)](https://pypi.org/project/etlutils/)
[![Documentation Status](https://readthedocs.org/projects/etlutils/badge/?version=latest)](https://etlutils.readthedocs.io/en/latest/?badge=latest)
![Python package](https://github.com/kevingoldsmith/etlutils/workflows/Python%20package/badge.svg)
[![contributions welcome](https://img.shields.io/badge/contributions-welcome-brightgreen.svg?style=flat)](https://github.com/kevingoldsmith/etlutils/issues)
[![Twitter](https://img.shields.io/twitter/follow/kevingoldsmith?style=plastic)](https://img.shields.io/twitter/follow/kevingoldsmith?style=plastic)

# etlutils

This is a collection of utility functions for my etl projects. Sharing as they might be useful to others as well.

## current version

The current version is 0.2.2 as this is a very early release. Use at your own risk as things will change.

## documentation

Read the documentation on [readthedocs](https://etlutils.readthedocs.io/en/latest/)

## installing with pip

    pip install etlutils

## building for development

    make init
    pip install -e .
    make test
    make lint

## contributions

All contributions are welcome, please submit a PR. Issues and feature requests are fine as well, but they may take some time for me to get to. Better to submit a PR.

## requires

Python 3.6 or above, I'm not using any earlier versions of python on any of my projects anymore, so supporting older versions isn't high on my list of priorities.
